@@ -9,7 +9,6 @@ package org.sablecc.sablecc;
 
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.util.*;
 
 public class AcceptStates extends DepthFirstAdapter
 {
@@ -24,6 +23,7 @@ public class AcceptStates extends DepthFirstAdapter
     this.stateName = stateName;
   }
 
+  @Override
   public void caseStart(Start node)
   {
     for(int i = 0; i < dfa.states.size(); i++)
