@@ -7,7 +7,6 @@
 
 package org.sablecc.sablecc;
 
-import java.util.*;
 
 public class BooleanCast implements Cast
 {
@@ -16,6 +15,7 @@ public class BooleanCast implements Cast
   private BooleanCast()
   {}
 
+  @Override
   public  Object cast(Object o)
   {
     return (Boolean) o;
