@@ -7,9 +7,9 @@
 
 package org.sablecc.sablecc;
 
-import org.sablecc.sablecc.node.*;
-import java.util.Set;
+import java.util.*;
 
+@SuppressWarnings("rawtypes")
 public class ConflictException extends Exception
 {
   private Set conflictualProductions;
