@@ -8,9 +8,11 @@
 package org.sablecc.sablecc;
 
 import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class ConstructProdsMap extends DepthFirstAdapter
 {
   public Map productionsMap =
@@ -19,6 +21,7 @@ public class ConstructProdsMap extends DepthFirstAdapter
 
   private String currentProd;
 
+  @Override
   public void caseAProd(AProd node)
   {
     currentProd = ResolveIds.name(node.getId().getText());
