@@ -7,13 +7,11 @@
 
 package org.sablecc.sablecc;
 
+import java.io.*;
 import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.io.*;
-import org.sablecc.sablecc.Grammar;
-import java.util.Vector;
-import java.util.Enumeration;
 
 /*
  * GenParser
@@ -28,6 +26,7 @@ import java.util.Enumeration;
  * resolving it.
  */
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class GenParser extends DepthFirstAdapter
 {
   //This is the tree-walker field which made internal transformations("EBNF"->BNF) to the grammar
@@ -120,10 +119,12 @@ public class GenParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseStart(Start tree)
   {
     tree.getPGrammar().apply(new DepthFirstAdapter()
                              {
+                               @Override
                                public void caseAProd(AProd node)
                                {
                                  hasProductions = true;
@@ -175,6 +176,7 @@ public class GenParser extends DepthFirstAdapter
                  {
                    private boolean hasAlternative;
 
+                   @Override
                    public void caseATokenDef(ATokenDef node)
                    {
                      String name = (String) ids.names.get(node);
@@ -186,16 +188,19 @@ public class GenParser extends DepthFirstAdapter
                      }
                    }
 
+                   @Override
                    public void inAProd(AProd node)
                    {
                      hasAlternative = false;
                    }
 
+                   @Override
                    public void inAAlt(AAlt node)
                    {
                      hasAlternative = true;
                    }
 
+                   @Override
                    public void outAProd(AProd node)
                    {
                      if(hasAlternative)
@@ -278,9 +283,10 @@ public class GenParser extends DepthFirstAdapter
   {
     tree.apply(new DepthFirstAdapter()
                {
+                 @Override
                  public void caseAProd(AProd node)
                  {
-                   currentProd = ids.name(node.getId().getText());
+                   currentProd = ResolveIds.name(node.getId().getText());
                    String name = "P" + currentProd;
 
                    ids.names.put(node, name);
@@ -293,26 +299,29 @@ public class GenParser extends DepthFirstAdapter
                    }
                  }
 
+                 @Override
                  public void outAHelperDef(AHelperDef node)
                  {
                    String name = node.getId().getText();
                    ids.names.put(node, name);
                  }
 
+                 @Override
                  public void outATokenDef(ATokenDef node)
                  {
-                   String name = "T" + ids.name(node.getId().getText());
+                   String name = "T" + ResolveIds.name(node.getId().getText());
 
                    ids.names.put(node, name);
                  }
 
+                 @Override
                  public void caseAAlt(final AAlt alt)
                  {
                    if(alt.getAltName() != null)
                    {
                      currentAlt =
                        "A" +
-                       ids.name(alt.getAltName().getText()) +
+                       ResolveIds.name(alt.getAltName().getText()) +
                        currentProd;
 
                      ids.names.put(alt, currentAlt);
@@ -330,18 +339,20 @@ public class GenParser extends DepthFirstAdapter
                    }
                  }
 
+                 @Override
                  public void caseAAst(AAst node)
                  {}
 
+                 @Override
                  public void caseAElem(final AElem elem)
                  {
                    if(elem.getElemName() != null)
                    {
-                     ids.names.put(elem, ids.name(elem.getElemName().getText()) );
+                     ids.names.put(elem, ResolveIds.name(elem.getElemName().getText()) );
                    }
                    else
                    {
-                     ids.names.put(elem, ids.name(elem.getId().getText()));
+                     ids.names.put(elem, ResolveIds.name(elem.getId().getText()));
                    }
                  }
                }
@@ -366,7 +377,7 @@ public class GenParser extends DepthFirstAdapter
 
     try
     {
-      Symbol[] terminals = Symbol.terminals();
+//      Symbol[] terminals = Symbol.terminals();
       Symbol[] nonterminals = Symbol.nonterminals();
       Production[] productions = Production.productions();
 
@@ -386,11 +397,24 @@ public class GenParser extends DepthFirstAdapter
         macros.apply(file, "ParserCommon", new String[] {"", ""});
       }
 
+      for(int i = 500; i < (productions.length - 1); i += 500) {
+          macros.apply(file, "ParseReduceElseIf", new String[] {"" + (i + 500), "" + i});
+      }
+      
+      macros.apply(file, "ParserParseTail", new String[] {firstProductionName});
+
+      macros.apply(file, "ParserReduceHead", new String[] {"0"});
+      
       //this loop generates the code for all possible reductions and the type of
       //the node needed to be created at a local point.
       for(int i = 0; i < (productions.length - 1); i++)
       {
-        Node node = (Node) alts.get(productions[i].name);
+//        Node node = (Node) alts.get(productions[i].name);
+          
+        if(i % 500 == 0 && i != 0) {
+            macros.apply(file, "ParserReduceTail", new String[] {});
+            macros.apply(file, "ParserReduceHead", new String[] {"" + i});            
+        }
 
         if(activateFilter && !grammarHasTransformations)
         {
@@ -410,7 +434,7 @@ public class GenParser extends DepthFirstAdapter
         }
       }
 
-      macros.apply(file, "ParserParseTail", new String[] {firstProductionName});
+      macros.apply(file, "ParserReduceTail", new String[] {});
 
       //the node creation code. Reduce methods definitions are done here
       for(int i = 0; i < (productions.length - 1); i++)
@@ -421,13 +445,14 @@ public class GenParser extends DepthFirstAdapter
 
         final Node node = (Node) alts.get(productions[i].name);
 
-        final BufferedWriter finalFile = file;
+//        final BufferedWriter finalFile = file;
         final LinkedList stack = new LinkedList();
 
         node.apply(new DepthFirstAdapter()
                    {
                      private int current;
 
+                     @Override
                      public void caseAElem(AElem elem)
                      {
                        current++;
@@ -838,7 +863,7 @@ public class GenParser extends DepthFirstAdapter
     catch(IOException e)
     {}
   }
-
+/*
   private int count(String name)
   {
     if(name.charAt(0) != 'X')
@@ -858,7 +883,8 @@ public class GenParser extends DepthFirstAdapter
 
     return Integer.parseInt(s.toString());
   }
-
+*/
+/*
   private String name(String name)
   {
     if(name.charAt(0) != 'X')
@@ -876,7 +902,7 @@ public class GenParser extends DepthFirstAdapter
 
     return name.substring(i);
   }
-
+*/
   static class Element
   {
     String macro;
