@@ -7,14 +7,13 @@
 
 package org.sablecc.sablecc;
 
+import java.io.*;
 import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.io.*;
-import org.sablecc.sablecc.Grammar;
-import java.util.Vector;
-import java.util.Enumeration;
 
+@SuppressWarnings("rawtypes")
 public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
 {
   String currentAlt;
@@ -54,6 +53,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     this.simpleTermOrsimpleListTermTypes = simpleTermOrsimpleListTermTypes;
   }
 
+  @Override
   public void inAAltTransform(AAltTransform node)
   {
     Object temp[] = node.getTerms().toArray();
@@ -96,6 +96,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAAltTransform(AAltTransform node)
   {
     Object temp[] = node.getTerms().toArray();
@@ -183,6 +184,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inASimpleTerm(ASimpleTerm node)
   {
     try
@@ -254,6 +256,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inASimpleListTerm(ASimpleListTerm node)
   {
     try
@@ -328,6 +331,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inANewTerm(ANewTerm node)
   {
     try
@@ -342,6 +346,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     inAParams(node.getParams());
   }
 
+  @Override
   public void inANewListTerm(ANewListTerm node)
   {
     try
@@ -356,6 +361,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     inAParams(node.getParams());
   }
 
+  @Override
   public void inAListTerm(AListTerm node)
   {
     try
@@ -397,6 +403,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAListTerm(AListTerm node)
   {
     try
@@ -438,6 +445,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outANewTerm(ANewTerm node)
   {
     String type_name = (String)CG.getAltTransformElemTypes().get(node);
@@ -515,6 +523,7 @@ public class GenerateAlternativeCodeForParser extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outANewListTerm(ANewListTerm node)
   {
     String type_name;
