@@ -17,9 +17,11 @@
 package org.sablecc.sablecc;
 
 import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class Inlining
 {
   public static HashSet productionsToBeRemoved =
@@ -53,6 +55,7 @@ public class Inlining
     {
       ((PAlt)alts[i]).apply( new DepthFirstAdapter()
                              {
+                               @Override
                                public void caseAElem(AElem node)
                                {
                                  String elem_name = node.getId().getText();
@@ -95,7 +98,12 @@ public class Inlining
       }
       return false;
       /**************************************************************************/
-      listOfAlts = (LinkedList)removeAlternativeDoubloonsFromInlinedProduction(listOfAlts);
+
+      // Etienne: Removing duplicate alternatives modifies the grammar; it could
+      // hide grammar ambiguities.
+      //
+      // So, I commented out the following line of code:
+      // listOfAlts = (LinkedList)removeAlternativeDoubloonsFromInlinedProduction(listOfAlts);
 
       //list of productions whose inlining was a success.
       productionsToBeRemoved.add("P" + ResolveIds.name(prod_to_inline.getName()));
@@ -258,6 +266,7 @@ public class Inlining
 
         aAltTransform.apply(new DepthFirstAdapter()
                             {
+                              @Override
                               public void caseASimpleTerm(ASimpleTerm node)
                               {
                                 if(node.getId().getText().equals(alt_elem_info)  &&
@@ -282,6 +291,7 @@ public class Inlining
                                 }
                               }
 
+                              @Override
                               public void caseASimpleListTerm(final ASimpleListTerm node_)
                               {
                                 if(node_.getId().getText().equals(alt_elem_info)  &&
@@ -307,6 +317,7 @@ public class Inlining
                                     {
                                       term.apply(new DepthFirstAdapter()
                                                  {
+                                                   @Override
                                                    public void caseANewTerm(ANewTerm node)
                                                    {
                                                      node_.replaceBy( new ANewListTerm(   (AProdName)node.getProdName().clone(),
@@ -316,6 +327,7 @@ public class Inlining
                                                                     );
                                                    }
 
+                                                   @Override
                                                    public void caseASimpleTerm(ASimpleTerm node)
                                                    {
                                                      PSpecifier specifier = null;
@@ -335,11 +347,13 @@ public class Inlining
                                                                     );
                                                    }
 
-                                                   public void caseNullTerm(ANullTerm node)
+                                                   @Override
+                                                   public void caseANullTerm(ANullTerm node)
                                                    {
                                                      node_.replaceBy( null );
                                                    }
 
+                                                   @Override
                                                    public void caseAListTerm(AListTerm node)
                                                    {
                                                      AListTerm parent = (AListTerm)node_.parent();
@@ -428,7 +442,7 @@ public class Inlining
     }
 
     LinkedList list = new LinkedList();
-    int elemPosition = 1;
+//    int elemPosition = 1;
 
     //Before the inlined element (old alternative elements)
     for(int i=0; i<position; i++)
@@ -473,6 +487,7 @@ public class Inlining
   {
     tmpaAltTransform.apply(new DepthFirstAdapter()
                            {
+                             @Override
                              public void caseASimpleTerm(ASimpleTerm node)
                              {
                                if(mapOldNameNewNames.get(node.getId().getText()) != null)
@@ -481,6 +496,7 @@ public class Inlining
                                }
                              }
 
+                             @Override
                              public void caseASimpleListTerm(ASimpleListTerm node)
                              {
                                if(mapOldNameNewNames.get(node.getId().getText()) != null)
