@@ -7,7 +7,6 @@
 
 package org.sablecc.sablecc;
 
-import java.util.*;
 
 public class IntegerCast implements Cast
 {
@@ -16,6 +15,7 @@ public class IntegerCast implements Cast
   private IntegerCast()
   {}
 
+  @Override
   public  Object cast(Object o)
   {
     return (Integer) o;
