@@ -9,6 +9,7 @@ package org.sablecc.sablecc;
 
 import java.util.*;
 
+@SuppressWarnings("rawtypes")
 public class IntegerComparator implements Comparator
 {
   public final static IntegerComparator instance = new IntegerComparator();
@@ -16,6 +17,7 @@ public class IntegerComparator implements Comparator
   private IntegerComparator()
   {}
 
+  @Override
   public int compare(Object o1, Object o2)
   {
     return ((Integer) o1).intValue() - ((Integer) o2).intValue();
