@@ -16,10 +16,11 @@
 package org.sablecc.sablecc;
 
 import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.io.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class InternalTransformationsToGrammar extends DepthFirstAdapter
 {
 
@@ -27,10 +28,10 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
   private ResolveAltIds altIds;
   private ResolveTransformIds transformIds;
   private String currentProd;
-  private int currentAlt;
+//  private int currentAlt;
   private String currentAltName;
   private boolean processingAst;
-  private boolean processingProdTransform;
+//  private boolean processingProdTransform;
 
   static final int NONE = 0;
   static final int STAR = 1;
@@ -69,6 +70,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     this.simpleTermOrsimpleListTermTypes = simpleTermOrsimpleListTermTypes;
   }
 
+  @Override
   public void inAProductions(AProductions node)
   {
     listProd = node.getProds();
@@ -76,16 +78,19 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
   private LinkedList listOfAlts;
 
+  @Override
   public void inAAst(AAst node)
   {
     processingAst = true;
   }
 
+  @Override
   public void outAAst(AAst node)
   {
     processingAst = false;
   }
 
+  @Override
   public void caseAProd(AProd node)
   {
     currentProd = (String) ids.names.get(node);
@@ -109,6 +114,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
   LinkedList listOfAlternativeElemsWHaveName;
 
+  @Override
   public void caseAAlt(AAlt node)
   {
     count = 1;
@@ -120,23 +126,27 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
     node.apply(new DepthFirstAdapter()
                {
+                 @Override
                  public void inAElem(AElem node)
                  {
                    InternalTransformationsToGrammar.this.setOut(node, new Integer(NONE));
                  }
 
+                 @Override
                  public void caseAStarUnOp(AStarUnOp node)
                  {
                    count *= 2;
                    InternalTransformationsToGrammar.this.setOut(node.parent(), new Integer(STAR));
                  }
 
+                 @Override
                  public void caseAQMarkUnOp(AQMarkUnOp node)
                  {
                    count *= 2;
                    InternalTransformationsToGrammar.this.setOut(node.parent(), new Integer(QMARK));
                  }
 
+                 @Override
                  public void caseAPlusUnOp(APlusUnOp node)
                  {
                    InternalTransformationsToGrammar.this.setOut(node.parent(), new Integer(PLUS));
@@ -253,7 +263,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
         aParsedAlt = new AAlt(new TId(currentAltName.toLowerCase()+(count + 1)), listElems, altTransform);
 
         String currentAltInlining;
-        currentAltInlining = "A" + ids.name(aParsedAlt.getAltName().getText()) + currentProd;
+        currentAltInlining = "A" + ResolveIds.name(aParsedAlt.getAltName().getText()) + currentProd;
         ids.names.put(aParsedAlt, currentAltInlining);
 
         listOfAlts.add(aParsedAlt);
@@ -264,6 +274,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
   LinkedList checkCreationOfXElem = new TypedLinkedList(StringCast.instance);
 
   //It's also available for Ignored alternatives
+  @Override
   public void caseAElem(AElem node)
   {
     if(!processingAst)
@@ -307,11 +318,11 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
           aElem = new AElem(aElemName, specifier, new TId(elemName), null);
           if(elemNameOfElem != null)
           {
-            ids.names.put(aElem, ids.name(elemNameOfElem));
+            ids.names.put(aElem, ResolveIds.name(elemNameOfElem));
           }
           else
           {
-            ids.names.put(aElem, ids.name(elemName));
+            ids.names.put(aElem, ResolveIds.name(elemName));
           }
           ok = true;
         }
@@ -336,11 +347,11 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
             if(elemNameOfElem != null)
             {
-              ids.names.put(aElem, ids.name(elemNameOfElem));
+              ids.names.put(aElem, ResolveIds.name(elemNameOfElem));
             }
             else
             {
-              ids.names.put(aElem, ids.name(elemName));
+              ids.names.put(aElem, ResolveIds.name(elemName));
             }
 
             ok = true;
@@ -358,11 +369,11 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
             if(elemNameOfElem != null)
             {
-              ids.names.put(aElem, ids.name(elemNameOfElem));
+              ids.names.put(aElem, ResolveIds.name(elemNameOfElem));
             }
             else
             {
-              ids.names.put(aElem, ids.name(elemName));
+              ids.names.put(aElem, ResolveIds.name(elemName));
             }
 
             ok = true;
@@ -388,11 +399,11 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
           if(elemNameOfElem != null)
           {
-            ids.names.put(aElem, ids.name(elemNameOfElem));
+            ids.names.put(aElem, ResolveIds.name(elemNameOfElem));
           }
           else
           {
-            ids.names.put(aElem, ids.name(elemName));
+            ids.names.put(aElem, ResolveIds.name(elemName));
           }
 
           ok = true;
@@ -477,7 +488,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     //That means elem is token type
     else
     {
-      String name_resolved = ids.name(name);
+//      String name_resolved = ResolveIds.name(name);
 
       LinkedList elemsProdTransform = new LinkedList();
       elemsProdTransform.add( new AElem( null, new ATokenSpecifier(), new TId(rname), new AStarUnOp() ) );
@@ -491,6 +502,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     {
       temp_listProdTransform[i].apply( new DepthFirstAdapter()
                                        {
+                                         @Override
                                          public void caseAElem(AElem node)
                                          {
                                            //The production transformation needs to have a star operator.
@@ -517,6 +529,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     {
       prodTransformElems[i].apply(new AnalysisAdapter()
                                   {
+                                    @Override
                                     public void caseAElem(AElem node)
                                     {
                                       String tmpNodeName = ( (node.getElemName() == null) ? node.getId().getText() :
@@ -557,7 +570,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
     //creation of the first alternative
     AAlt aParsedAlt = new AAlt(new TId("terminal"), elems, aAltTransform);
-    String terminal_altName = "ATerminal" + ids.name(name);
+//    String terminal_altName = "ATerminal" + ResolveIds.name(name);
 
     listOfAltsXelem.add(aParsedAlt);
 
@@ -570,6 +583,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     {
       prodTransformElems[i].apply(new AnalysisAdapter()
                                   {
+                                    @Override
                                     public void caseAElem(AElem node)
                                     {
                                       String tmpNodeName = ( (node.getElemName() == null) ? node.getId().getText() :
@@ -619,7 +633,7 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
 
     aParsedAlt = new AAlt(new TId("non_terminal"), elems, aAltTransform);
 
-    String nonTerminal_altName = "ANonTerminal" + ids.name(name);
+//    String nonTerminal_altName = "ANonTerminal" + ResolveIds.name(name);
 
     listOfAltsXelem.add(aParsedAlt);
 
@@ -640,10 +654,10 @@ public class InternalTransformationsToGrammar extends DepthFirstAdapter
     }
     return clone;
   }
-
+/*
   private String xproductionType(String name)
   {
     return "P$" + name.substring(1).toLowerCase();
   }
-
+*/
 }
