@@ -7,7 +7,6 @@
 
 package org.sablecc.sablecc;
 
-import java.util.*;
 import org.sablecc.sablecc.node.*;
 
 public class NodeCast implements Cast
@@ -17,6 +16,7 @@ public class NodeCast implements Cast
   private NodeCast()
   {}
 
+  @Override
   public Object cast(Object o)
   {
     return (Node) o;
