@@ -7,11 +7,13 @@
 
 package org.sablecc.sablecc;
 
+import java.io.*;
+import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.util.*;
-import java.io.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class ResolveIds extends DepthFirstAdapter
 {
   public final Map helpers = new TypedTreeMap(
@@ -73,8 +75,8 @@ public class ResolveIds extends DepthFirstAdapter
   public File pkgDir;
   public String pkgName = "";
 
-  private boolean processingStates;
-  private boolean processingIgnTokens;
+//  private boolean processingStates;
+//  private boolean processingIgnTokens;
 
   String currentProd;
   String currentAlt;
@@ -86,6 +88,7 @@ public class ResolveIds extends DepthFirstAdapter
     pkgDir = currentDir;
   }
 
+  @Override
   public void inAGrammar(AGrammar node)
   {
     TPkgId[] temp = (TPkgId []) node.getPackage().toArray(new TPkgId[0]);
@@ -110,6 +113,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseAProd(AProd node)
   {
     //inAProd code.
@@ -131,6 +135,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseAIdBasic(AIdBasic node)
   {
     String name = node.getId().getText();
@@ -142,6 +147,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAHelperDef(AHelperDef node)
   {
     String name = node.getId().getText();
@@ -156,6 +162,7 @@ public class ResolveIds extends DepthFirstAdapter
     names.put(node, name);
   }
 
+  @Override
   public void outATokenDef(ATokenDef node)
   {
     String name = "T" + name(node.getId().getText());
@@ -180,6 +187,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inAStates(AStates node)
   {
     Object [] list_id = (Object[]) node.getListId().toArray();
@@ -199,6 +207,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inAIgnTokens(AIgnTokens node)
   {
     Object [] list_id = (Object[]) node.getListId().toArray();
@@ -223,6 +232,7 @@ public class ResolveIds extends DepthFirstAdapter
 
   private Map stateMap;
 
+  @Override
   public void inAStateList(AStateList node)
   {
     stateMap = new TypedTreeMap(
@@ -243,11 +253,13 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAStateList(AStateList node)
   {
     stateMap = null;
   }
 
+  @Override
   public void inAStateListTail(AStateListTail node)
   {
     String name = node.getId().getText().toUpperCase();
@@ -263,6 +275,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void inATransition(ATransition node)
   {
     String name = node.getId().getText().toUpperCase();
@@ -273,6 +286,7 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseAAlt(final AAlt alt)
   {
     if(alt.getAltName() != null)
@@ -319,9 +333,11 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseAAst(AAst node)
   {}
 
+  @Override
   public void caseAElem(final AElem elem)
   {
     if(elem.getElemName() != null)
@@ -360,10 +376,12 @@ public class ResolveIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAProductions(AProductions prod)
   {
     prod.apply(new DepthFirstAdapter()
                {
+                 @Override
                  public void caseAProd(AProd node)
                  {
                    //inAProd code.
@@ -377,6 +395,7 @@ public class ResolveIds extends DepthFirstAdapter
                    }
                  }
 
+                 @Override
                  public void caseAAlt(final AAlt alt)
                  {
                    if(alt.getAltName() != null)
@@ -395,6 +414,7 @@ public class ResolveIds extends DepthFirstAdapter
                    }
                  }
 
+                 @Override
                  public void caseAElem(AElem node)
                  {
                    String name = name(node.getId().getText());
@@ -627,6 +647,7 @@ public class ResolveIds extends DepthFirstAdapter
       "class is an invalid element name.");
   }
 
+  @Override
   public String toString()
   {
     StringBuffer s = new StringBuffer();
