@@ -7,10 +7,10 @@
 
 package org.sablecc.sablecc;
 
+import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.util.*;
-import java.io.*;
 
 /*
  * ResolveProdTransformIds
@@ -21,6 +21,7 @@ import java.io.*;
  * are defined as production in the section Abstract Syntax Tree.
  */
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class ResolveProdTransformIds extends DepthFirstAdapter
 {
   private ResolveAstIds transformIds;
@@ -61,6 +62,7 @@ public class ResolveProdTransformIds extends DepthFirstAdapter
     transformIds = ids;
   }
 
+  @Override
   public void caseAProd(final AProd production)
   {
     prod_name = (String)transformIds.astIds.names.get(production);
@@ -81,6 +83,7 @@ public class ResolveProdTransformIds extends DepthFirstAdapter
     {
       ((PElem) temp[i]).apply(new DepthFirstAdapter()
                               {
+                                @Override
                                 public void caseAElem(AElem node)
                                 {
                                   String rname = node.getId().getText();
@@ -216,7 +219,7 @@ public class ResolveProdTransformIds extends DepthFirstAdapter
                                   else
                                   {
                                     Object token = transformIds.astIds.tokens.get("T" + name);
-                                    Object ignToken = transformIds.astIds.ignTokens.get("T" + name);
+//                                    Object ignToken = transformIds.astIds.ignTokens.get("T" + name);
                                     Object production = transformIds.astIds.prods.get("P" + name);
                                     Object ast_production = transformIds.ast_prods.get("P" + name);
 
@@ -228,7 +231,7 @@ public class ResolveProdTransformIds extends DepthFirstAdapter
                                     //it seems to be a token
                                     if(token != null)
                                     {
-                                      boolean bast_production = false;
+//                                      boolean bast_production = false;
                                       //if it's also a ast_production
                                       if(ast_production != null)
                                       {
