@@ -11,10 +11,10 @@
  */
 package org.sablecc.sablecc;
 
+import java.util.*;
+
 import org.sablecc.sablecc.analysis.*;
 import org.sablecc.sablecc.node.*;
-import java.util.*;
-import java.io.*;
 
 /*
  * ResolveTransformIds
@@ -25,6 +25,7 @@ import java.io.*;
  * the alternative transformation is itself correct.
  */
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class ResolveTransformIds extends DepthFirstAdapter
 {
 
@@ -36,7 +37,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
   private int nbTransformProd = 0;
   private String currentAstAlt;
   private String currentAstProd;
-  private String currentProd;
+//  private String currentProd;
   private String currentAlt;
   private String currentAstProdName;
 
@@ -65,10 +66,11 @@ public class ResolveTransformIds extends DepthFirstAdapter
     return prodTransformIds;
   }
 
+  @Override
   public void inAProd(final AProd production)
   {
     nbTransformProd = 0;
-    currentProd = (String)altIds.ids.names.get(production);
+//    currentProd = (String)altIds.ids.names.get(production);
 
     if(production.getArrow() != null)
     {
@@ -80,6 +82,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
   private LinkedList listCurrentAlt;
   private LinkedList listOfListCurrentAlt;
 
+  @Override
   public void inAAlt(AAlt nodeAlt)
   {
     nbTransformAlt = 0;
@@ -90,6 +93,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
     listOfListCurrentAlt = (LinkedList)((LinkedList)altIds.alts_elems_list.get(currentAlt)).clone();
   }
 
+  @Override
   public void inAAltTransform(AAltTransform node)
   {
     if(node.getTerms().size() == 0)
@@ -102,6 +106,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAAltTransform(AAltTransform node)
   {
     if(nbTransformAlt != nbTransformProd)
@@ -110,6 +115,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAAlt(AAlt node)
   {
     lastSimpleTerm = null;
@@ -120,9 +126,10 @@ public class ResolveTransformIds extends DepthFirstAdapter
     mapSimpleTermProdTransformation.clear();
   }
 
+  @Override
   public void outANewTerm(ANewTerm node)
   {
-    LinkedList list = (LinkedList)prodTransformIds.prod_transforms.get(currentProd);
+//    LinkedList list = (LinkedList)prodTransformIds.prod_transforms.get(currentProd);
     AProdName prodNameNode = (AProdName)node.getProdName();
 
     currentAstProd = "P" + ResolveIds.name(prodNameNode.getId().getText());
@@ -138,14 +145,14 @@ public class ResolveTransformIds extends DepthFirstAdapter
       currentAstAlt = "A" + ResolveIds.name(prodNameNode.getId().getText());
     }
 
-    String currentAstProdName_no_specifier;
+//    String currentAstProdName_no_specifier;
     if(currentAstProdName.startsWith("P."))
     {
-      currentAstProdName_no_specifier = currentAstProdName.substring(2);
+//      currentAstProdName_no_specifier = currentAstProdName.substring(2);
     }
     else
     {
-      currentAstProdName_no_specifier = currentAstProdName;
+//      currentAstProdName_no_specifier = currentAstProdName;
     }
 
     if(transformIds.ast_prods.get(currentAstProd) == null)
@@ -210,9 +217,10 @@ public class ResolveTransformIds extends DepthFirstAdapter
 
   }
 
+  @Override
   public void outANewListTerm(ANewListTerm node)
   {
-    LinkedList list = (LinkedList)prodTransformIds.prod_transforms.get(currentProd);
+//    LinkedList list = (LinkedList)prodTransformIds.prod_transforms.get(currentProd);
     AProdName prodNameNode = (AProdName)node.getProdName();
 
     currentAstProdName = prodNameNode.getId().getText();
@@ -228,14 +236,14 @@ public class ResolveTransformIds extends DepthFirstAdapter
       currentAstAlt = "A" + ResolveIds.name(prodNameNode.getId().getText());
     }
 
-    String currentAstProdName_no_specifier;
+//    String currentAstProdName_no_specifier;
     if(currentAstProdName.startsWith("P."))
     {
-      currentAstProdName_no_specifier = currentAstProdName.substring(2);
+//      currentAstProdName_no_specifier = currentAstProdName.substring(2);
     }
     else
     {
-      currentAstProdName_no_specifier = currentAstProdName;
+//      currentAstProdName_no_specifier = currentAstProdName;
     }
 
     if(transformIds.ast_prods.get(currentAstProd) == null)
@@ -300,6 +308,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void outAListTerm(AListTerm node)
   {
     if( (node.getListTerms() != null) && (node.getListTerms().size() != 0) )
@@ -344,13 +353,14 @@ public class ResolveTransformIds extends DepthFirstAdapter
   private LinkedList listP;
   private String lastSimpleTerm;
 
+  @Override
   public void inASimpleTerm(ASimpleTerm node)
   {
     String name = node.getId().getText();
     String typeOfExplicitElemName = (String)transformIds.astIds.altsElemNameTypes.get( currentAlt+"."+node.getId().getText() );
     String alternativeElemType = (String)transformIds.astIds.altsElemTypes.get( currentAlt+"."+node.getId().getText() );
 
-    boolean okTermtail = false;
+//    boolean okTermtail = false;
     String tmpName = name;
 
     if( (listCurrentAltGlobal == null) || !listCurrentAltGlobal.contains(name) )
@@ -397,9 +407,9 @@ public class ResolveTransformIds extends DepthFirstAdapter
       }
     }
 
-    int position = 0;
+//    int position = 0;
 
-    String type;
+//    String type;
 
     if(alternativeElemType.startsWith("T"))
     {
@@ -409,7 +419,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       }
 
       altTransformElemTypes.put(node, alternativeElemType);
-      position = 0;
+//      position = 0;
     }
     //The element is a production
     else
@@ -477,7 +487,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       //simpletermtail doesn't appear in the production transformation
       if( node.getSimpleTermTail() != null )
       {
-        okTermtail = true;
+//        okTermtail = true;
         String strTermTail = node.getSimpleTermTail().getText();
 
         if( ( (listL == null) || !listL.contains(strTermTail) ) &&
@@ -493,7 +503,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
           {
             iter = listL.listIterator();
 
-            position = listL.indexOf(strTermTail);
+//            position = listL.indexOf(strTermTail);
 
             while(iter.hasNext())
             {
@@ -509,7 +519,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
           {
             iter = listP.listIterator();
 
-            position = listP.indexOf(strTermTail);
+//            position = listP.indexOf(strTermTail);
 
             while(iter.hasNext())
             {
@@ -526,15 +536,15 @@ public class ResolveTransformIds extends DepthFirstAdapter
 
       if(node.getSimpleTermTail() != null)
       {
-        String termtail = node.getSimpleTermTail().getText();
-        LinkedList listProdContains = null;
+//        String termtail = node.getSimpleTermTail().getText();
+//        LinkedList listProdContains = null;
         if(typeOfExplicitElemName != null)
         {
-          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get(typeOfExplicitElemName);
+//          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get(typeOfExplicitElemName);
         }
         else
         {
-          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get("P" + ResolveIds.name(node.getId().getText()));
+//          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get("P" + ResolveIds.name(node.getId().getText()));
         }
       }
       //The Type of the element without his eventual termtail (term.termtail :: (type of term))
@@ -550,7 +560,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       if(node.getSimpleTermTail() == null)
       {
         altTransformElemTypes.put(node, alternativeElemType);
-        position = 0;
+//        position = 0;
       }
       else
       {
@@ -578,11 +588,13 @@ public class ResolveTransformIds extends DepthFirstAdapter
     }
   }
 
+  @Override
   public void caseANullTerm(ANullTerm node)
   {
     altTransformElemTypes.put(node, "Null");
   }
 
+  @Override
   public void inASimpleListTerm(ASimpleListTerm node)
   {
     String name = node.getId().getText();
@@ -642,9 +654,9 @@ public class ResolveTransformIds extends DepthFirstAdapter
       }
     }
 
-    int position = 0;
+//    int position = 0;
 
-    String type;
+//    String type;
     if(alternativeElemType.startsWith("T"))
     {
       //A token can't have term tail
@@ -654,7 +666,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       }
 
       altTransformElemTypes.put(node, alternativeElemType);
-      position = 0;
+//      position = 0;
     }
     //it seems to be a production without a specifier
     else
@@ -735,7 +747,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
           {
             iter = listL.listIterator();
 
-            position = listL.indexOf(strTermTail);
+//            position = listL.indexOf(strTermTail);
 
             while(iter.hasNext())
             {
@@ -751,7 +763,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
           {
             iter = listP.listIterator();
 
-            position = listP.indexOf(strTermTail);
+//            position = listP.indexOf(strTermTail);
 
             while(iter.hasNext())
             {
@@ -767,21 +779,21 @@ public class ResolveTransformIds extends DepthFirstAdapter
 
       if(node.getSimpleTermTail() != null)
       {
-        String termtail = node.getSimpleTermTail().getText();
-        LinkedList listProdContains = null;
-        LinkedList prodContains = null;
+//        String termtail = node.getSimpleTermTail().getText();
+//        LinkedList listProdContains = null;
+//        LinkedList prodContains = null;
         if(typeOfExplicitElemName != null)
         {
-          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get(typeOfExplicitElemName);
-          prodContains = (LinkedList)prodTransformIds.prod_transforms.get(typeOfExplicitElemName);
+//          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get(typeOfExplicitElemName);
+//          prodContains = (LinkedList)prodTransformIds.prod_transforms.get(typeOfExplicitElemName);
         }
         else
         {
-          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get("P" + ResolveIds.name(node.getId().getText()));
-          prodContains = (LinkedList)prodTransformIds.prod_transforms.get("P" + ResolveIds.name(node.getId().getText()));
+//          listProdContains = (LinkedList)prodTransformIds.mapProdTransformContainsList.get("P" + ResolveIds.name(node.getId().getText()));
+//          prodContains = (LinkedList)prodTransformIds.prod_transforms.get("P" + ResolveIds.name(node.getId().getText()));
         }
 
-        LinkedList lst = (LinkedList)altIds.alts_elems_list.get(currentAlt);
+//        LinkedList lst = (LinkedList)altIds.alts_elems_list.get(currentAlt);
       }
 
       //The Type of the element without his eventual termtail (term.termtail :: (type of term))
@@ -798,7 +810,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       if(node.getSimpleTermTail() == null)
       {
         altTransformElemTypes.put(node, alternativeElemType);
-        position = 0;
+//        position = 0;
       }
       else
       {
@@ -830,6 +842,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
   private boolean curr_prod_has_prodTransform;
   private boolean firstProduction = false;
 
+  @Override
   public void outAProductions(AProductions node)
   {
     LinkedList list = node.getProds();
@@ -847,6 +860,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
 
       ((PProd) temp[i]).apply(new DepthFirstAdapter()
                               {
+                                @Override
                                 public void inAProd(AProd production)
                                 {
                                   LinkedList prodTransform = production.getProdTransform();
@@ -888,6 +902,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
                                   }
                                 }
 
+                                @Override
                                 public void inAAltTransform(AAltTransform node)
                                 {
                                   Object curr_altTransformTerms[] = node.getTerms().toArray();
@@ -1080,6 +1095,7 @@ public class ResolveTransformIds extends DepthFirstAdapter
       "The first production's transformation must be only one elements without an operator.");
   }
 
+  @Override
   public String toString()
   {
     StringBuffer s = new StringBuffer();
