@@ -7,7 +7,6 @@
 
 package org.sablecc.sablecc;
 
-import java.util.*;
 
 public class StringCast implements Cast
 {
@@ -16,6 +15,7 @@ public class StringCast implements Cast
   private StringCast()
   {}
 
+  @Override
   public  Object cast(Object o)
   {
     return (String) o;
