@@ -9,6 +9,7 @@ package org.sablecc.sablecc;
 
 import java.util.*;
 
+@SuppressWarnings("rawtypes")
 public class StringComparator implements Comparator
 {
   public final static StringComparator instance = new StringComparator();
@@ -16,6 +17,7 @@ public class StringComparator implements Comparator
   private StringComparator()
   {}
 
+  @Override
   public int compare(Object o1, Object o2)
   {
     return ((String) o1).compareTo((String) o2);
