@@ -9,6 +9,7 @@ package org.sablecc.sablecc;
 
 import java.util.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class TypedHashMap extends HashMap
 {
   private Cast keyCast;
@@ -54,6 +55,7 @@ public class TypedHashMap extends HashMap
     this.valueCast = valueCast;
   }
 
+  @Override
   public Object clone()
   {
     return new TypedHashMap(this, keyCast, valueCast);
@@ -84,6 +86,7 @@ public class TypedHashMap extends HashMap
     return valueCast;
   }
 
+  @Override
   public Set entrySet()
   {
     if(entries == null)
@@ -94,6 +97,7 @@ public class TypedHashMap extends HashMap
     return entries;
   }
 
+  @Override
   public Object put(Object key, Object value)
   {
     return super.put(keyCast.cast(key), valueCast.cast(value));
@@ -111,11 +115,13 @@ public class TypedHashMap extends HashMap
                    ;
     }
 
+    @Override
     public int size()
     {
       return set.size();
     }
 
+    @Override
     public Iterator iterator()
     {
       return new EntryIterator(set.iterator());
@@ -131,16 +137,19 @@ public class TypedHashMap extends HashMap
       this.iterator = iterator;
     }
 
+    @Override
     public boolean hasNext()
     {
       return iterator.hasNext();
     }
 
+    @Override
     public Object next()
     {
       return new TypedEntry((Map.Entry) iterator.next());
     }
 
+    @Override
     public void remove
       ()
     {
@@ -157,16 +166,19 @@ public class TypedHashMap extends HashMap
       this.entry = entry;
     }
 
+    @Override
     public Object getKey()
     {
       return entry.getKey();
     }
 
+    @Override
     public Object getValue()
     {
       return entry.getValue();
     }
 
+    @Override
     public Object setValue(Object value)
     {
       return entry.setValue(valueCast.cast(value));
