@@ -9,6 +9,7 @@ package org.sablecc.sablecc;
 
 import java.util.*;
 
+@SuppressWarnings({"rawtypes","unchecked"})
 public class TypedLinkedList extends LinkedList
 {
   Cast cast;
@@ -46,16 +47,19 @@ public class TypedLinkedList extends LinkedList
     return cast;
   }
 
+  @Override
   public void addFirst(Object o)
   {
     super.addFirst(cast.cast(o));
   }
 
+  @Override
   public void addLast(Object o)
   {
     super.addLast(cast.cast(o));
   }
 
+  @Override
   public ListIterator listIterator(int index)
   {
     return new TypedLinkedListIterator(super.listIterator(index));
@@ -70,48 +74,57 @@ public class TypedLinkedList extends LinkedList
       this.iterator = iterator;
     }
 
+    @Override
     public boolean hasNext()
     {
       return iterator.hasNext();
     }
 
+    @Override
     public Object next()
     {
       return iterator.next();
     }
 
+    @Override
     public boolean hasPrevious()
     {
       return iterator.hasPrevious();
     }
 
+    @Override
     public Object previous()
     {
       return iterator.previous();
     }
 
+    @Override
     public int nextIndex()
     {
       return iterator.nextIndex();
     }
 
+    @Override
     public int previousIndex()
     {
       return iterator.previousIndex();
     }
 
+    @Override
     public void remove
       ()
     {
       iterator.remove();
     }
 
+    @Override
     public void set
       (Object o)
     {
       iterator.set(cast.cast(o));
     }
 
+    @Override
     public void add
       (Object o)
     {
